Processor.App.ArticleUtils.article_extractor.ArticleExtractor.__init__ — CommonCrawl Extractor 1.0 documentation

Toggle navigation sidebar
Toggle in-page Table of Contents

# Processor.App.ArticleUtils.article_extractor.ArticleExtractor.__init__

ArticleExtractor.__init__(header_css_dict: Dict[str, str], header_extract_dict: Dict[str, Union[Callable[[Any], Any], List[Callable[[Any], Any]]]], article_css_dict: Dict[str, str], article_extract_dict: Dict[str, Union[Callable[[Any], Any], List[Callable[[Any], Any]]]], article_css_selector: str, filter_must_exist: List[str] = [], filter_must_not_exist: List[str] = [], filter_allowed_domain_prefixes: Optional[List[str]] = None)